Package: epitraxr
Title: Manipulate 'EpiTrax' Data and Generate Reports
Version: 0.5.0
Authors@R: c(
    person("Andrew", "Pulsipher", , "pulsipher.a@gmail.com", role = c("aut", "cre"),
           comment = c(ORCID = "0000-0002-0773-3210")),
    person("Nate", "Lanza", , "natelanzadevelopment@gmail.com", role = c("aut", "ctb")),
    person("Centers for Disease Control and Prevention's Center for Forecasting and Outbreak Analytics", role = "fnd",
           comment = "Cooperative agreement CDC-RFA-FT-23-0069")
  )
Description: A fast, flexible tool for generating disease surveillance
    reports from data exported from 'EpiTrax', a central repository for
    epidemiological data used by public health officials. It provides
    functions to manipulate 'EpiTrax' datasets, tailor reports to internal
    or public use, and export reports in CSV, Excel 'xlsx', or PDF formats.
License: MIT + file LICENSE
URL: https://epiforesite.github.io/epitraxr/,
        https://github.com/EpiForeSITE/epitraxr
BugReports: https://github.com/EpiForeSITE/epitraxr/issues
Depends: R (>= 4.1.0)
Imports: lubridate, stats, utils, writexl, yaml
Suggests: DT, kableExtra, knitr, readxl, rmarkdown, shiny, shinyjs,
        stringr, tinytest
VignetteBuilder: knitr
Encoding: UTF-8
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-09-09 20:14:40 UTC; runner
Author: Andrew Pulsipher [aut, cre] (ORCID:
    <https://orcid.org/0000-0002-0773-3210>),
  Nate Lanza [aut, ctb],
  Centers for Disease Control and Prevention's Center for Forecasting and
    Outbreak Analytics [fnd] (Cooperative agreement CDC-RFA-FT-23-0069)
Maintainer: Andrew Pulsipher <pulsipher.a@gmail.com>
Repository: CRAN
Date/Publication: 2025-09-14 16:20:02 UTC
Built: R 4.6.0; ; 2026-04-27 09:06:51 UTC; unix
